[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[project]
name = "{{ project_name }}"
version = "0.1.0"
description = "Add your description here"
readme = "README.md"
requires-python = ">=3.11"
dependencies = []
{% if with_dev_dependencies %}

[project.optional-dependencies]
dev = [
    "pytest-cov>=7.0.0",
    "pytest-html>=4.1.1",
    "pytest==9.0.2",
    "pre-commit==4.5.1",
    "marimo==0.18.4",
    "pdoc>=16.0.0",
]
{% endif %}

[tool.hatch.build.targets.wheel]
packages = ["src/{{ package_name }}"]
{% if with_dev_dependencies %}

[tool.deptry]
# see https://deptry.com/usage/#pep-621-dev-dependency-groups
pep621_dev_dependency_groups = ["dev"]
{% endif %}
